@@ -2,8 +2,8 @@ use crate::Input;
 
 pub fn solve(input: &mut Input) -> Result<u64, String> {
     let words = input.text.split(' ').collect::<Vec<_>>();
-    if words.len() != 19 {
-        return Err("Invalid input - not 19 words".to_string());
+    if words.len() != 19 || words[16].is_empty() || words[18].is_empty() {
+        return Err("Invalid input - not expected structure".to_string());
     }
 
     let wanted_row = words[16][0..(words[16].len() - 1)]
